@@ -144,7 +144,7 @@
 
 #define wxUSE_ON_FATAL_EXCEPTION 1
 
-#define wxUSE_STACKWALKER 0
+#define wxUSE_STACKWALKER 1
 
 #define wxUSE_DEBUGREPORT 1
 
@@ -266,7 +266,7 @@
 
 #define wxUSE_ZLIB 1
 
-#define wxUSE_LIBLZMA 0
+#define wxUSE_LIBLZMA 1
 
 #define wxUSE_APPLE_IEEE 1
 
@@ -322,7 +322,7 @@
 
 #define wxUSE_STC 1
 
-#define wxUSE_WEBVIEW 0
+#define wxUSE_WEBVIEW 1
 
 #ifdef __WXMSW__
 #define wxUSE_WEBVIEW_IE 0
@@ -335,15 +335,15 @@
 #define wxUSE_WEBVIEW_EDGE_STATIC 0
 
 #if (defined(__WXGTK__) && !defined(__WXGTK3__)) || defined(__WXOSX__)
-#define wxUSE_WEBVIEW_WEBKIT 1
+#define wxUSE_WEBVIEW_WEBKIT 0
 #else
-#define wxUSE_WEBVIEW_WEBKIT 1
+#define wxUSE_WEBVIEW_WEBKIT 0
 #endif
 
 #if defined(__WXGTK3__)
-#define wxUSE_WEBVIEW_WEBKIT2 0
+#define wxUSE_WEBVIEW_WEBKIT2 1
 #else
-#define wxUSE_WEBVIEW_WEBKIT2 0
+#define wxUSE_WEBVIEW_WEBKIT2 1
 #endif
 
 
@@ -471,7 +471,7 @@
 
 #define wxUSE_PREFERENCES_EDITOR 1
 
-#define wxUSE_PRIVATE_FONTS 0
+#define wxUSE_PRIVATE_FONTS 1
 
 #define wxUSE_RICHTOOLTIP 1
 
@@ -587,7 +587,7 @@
 #define wxUSE_MOUSEWHEEL 1
 
 
-#define wxUSE_UIACTIONSIMULATOR 0
+#define wxUSE_UIACTIONSIMULATOR 1
 
 
 #define wxUSE_POSTSCRIPT 1
@@ -666,7 +666,7 @@
 
    Recommended setting: 1, wxUIActionSimulator won't work in wxGTK3 without it.
  */
-#define wxUSE_XTEST 0
+#define wxUSE_XTEST 1
 
 /* --- start MSW options --- */
 
@@ -789,17 +789,17 @@
 /*
  * Define if your compiler has std::tr1::unordered_map
  */
-/* #undef HAVE_TR1_UNORDERED_MAP */
+#define HAVE_TR1_UNORDERED_MAP 1
 
 /*
  * Define if your compiler has std::tr1::unordered_set
  */
-/* #undef HAVE_TR1_UNORDERED_SET */
+#define HAVE_TR1_UNORDERED_SET 1
 
 /*
  * Define if your compiler has <tr1/type_traits>
  */
-/* #undef HAVE_TR1_TYPE_TRAITS */
+#define HAVE_TR1_TYPE_TRAITS 1
 
 /*
  * Define if your compiler has <type_traits>
@@ -877,7 +877,7 @@
 /*
  * Use MS HTML Help via libmspack (Unix)
  */
-#define wxUSE_LIBMSPACK 0
+#define wxUSE_LIBMSPACK 1
 
 /*
  * Matthews garbage collection (used for MrEd?)
@@ -907,7 +907,7 @@
 
 
 /* define with the name of timezone variable */
-#define WX_TIMEZONE timezone
+#define WX_TIMEZONE __timezone
 
 /* The type of 3rd argument to getsockname() - usually size_t or int */
 #define WX_SOCKLEN_T socklen_t
@@ -938,7 +938,7 @@
 #define HAVE_PW_GECOS 1
 
 /* Define if you have __cxa_demangle() in <cxxabi.h> */
-/* #undef HAVE_CXA_DEMANGLE */
+#define HAVE_CXA_DEMANGLE 1
 
 /* Define if you have dlopen() */
 #define HAVE_DLOPEN 1
@@ -1229,7 +1229,7 @@
 #define HAVE_SYS_SELECT_H 1
 
 /* Define if you have abi::__forced_unwind in your <cxxabi.h>. */
-/* #undef HAVE_ABI_FORCEDUNWIND */
+#define HAVE_ABI_FORCEDUNWIND 1
 
 /* Define if fdopen is available.  */
 #define HAVE_FDOPEN 1
